@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2012 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
                              const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Window(baseObject), duration_column("Duration", duration_renderer),
     license_column("License", license_renderer),
+    genre_column("Genre",  genre_renderer),
     song_and_artist_column("Song/Artist", song_and_artist_renderer),
     rating_column("Album\nRating", rating_renderer)
 {
@@ -73,7 +74,9 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
   license_column.set_cell_data_func
     (license_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_license));
   treeview->append_column(license_column);
-  treeview->append_column("Genre", songs_columns.genre);
+  genre_column.set_cell_data_func
+    (genre_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_genre));
+  treeview->append_column(genre_column);
   song_and_artist_column.set_cell_data_func
     (song_and_artist_renderer, sigc::mem_fun(*this, &VCMAWindow::cell_data_song_and_artist));
   treeview->append_column(song_and_artist_column);
@@ -100,14 +103,14 @@ VCMAWindow::VCMAWindow(BaseObjectType* baseObject,
 
   treeview->get_column(0)->set_sort_column(songs_columns.duration);
   treeview->get_column(1)->set_sort_column(songs_columns.license);
-  treeview->get_column(1)->set_fixed_width(100);
+  //treeview->get_column(1)->set_fixed_width(100);
   treeview->get_column(2)->set_sort_column(songs_columns.genre);
-  treeview->get_column(2)->set_fixed_width(100);
-  treeview->get_column(2)->set_max_width(100);
+  //treeview->get_column(2)->set_fixed_width(100);
+  //treeview->get_column(2)->set_max_width(100);
   treeview->get_column(2)->set_expand(false);
   treeview->get_column(3)->set_sort_column(songs_columns.song_title);
-  treeview->get_column(3)->set_min_width(50);
-  treeview->get_column(3)->set_max_width(200);
+  //treeview->get_column(3)->set_min_width(50);
+  //treeview->get_column(3)->set_max_width(200);
   treeview->get_column(3)->set_resizable(true);
   treeview->get_column(3)->set_expand(true);
   treeview->get_column(4)->set_sort_column(songs_columns.album_rating);
@@ -255,7 +258,7 @@ void VCMAWindow::on_play_song_clicked()
     {
       Gtk::TreeModel::Row row = *iterrow;
       guint32 track_id = row[songs_columns.track_id];
-      Glib::ustring url = String::ucompose("http://www.jamendo.com/get/track/id/track/audio/redirect/%1/?aue=ogg2", track_id);
+      Glib::ustring url = String::ucompose("http://storage-new.newjamendo.com/download/track/%1/mp32/", track_id);
 
       Glib::ustring cmd = Glib::find_program_in_path("totem") + " " + url;
       Glib::spawn_command_line_async(cmd);
@@ -340,16 +343,14 @@ void VCMAWindow::search_tracks_in_the_background(TrackList *track_list, guint32
   TrackList *songs = new TrackList();
   track_list->find_tracks_with_duration(min, max, *songs);
 
-  std::list<guint32> album_ids;
-  songs->get_album_ids(album_ids);
 
   contents->set_sensitive(true);
   contents->show_all();
 
-  for (std::list<guint32>::iterator i = album_ids.begin(); i != album_ids.end();
-       i++)
+  for (TrackList::const_iterator i = songs->get_tracks().begin(); 
+       i != songs->get_tracks().end(); i++)
     {
-      d_loader->check_album_license(*i, sigc::bind(sigc::mem_fun(*this, &VCMAWindow::on_album_license_loaded), songs), sigc::bind(sigc::mem_fun(*this, &VCMAWindow::on_album_license_not_loaded), songs));
+      d_loader->check_track_license((*i)->get_track_id(), sigc::bind(sigc::mem_fun(*this, &VCMAWindow::on_track_license_loaded), songs), sigc::bind(sigc::mem_fun(*this, &VCMAWindow::on_track_license_not_loaded), songs));
     }
 
   if (songs->size() == 0)
@@ -362,12 +363,12 @@ void VCMAWindow::search_tracks_in_the_background(TrackList *track_list, guint32
   return;
 }
 
-void VCMAWindow::on_album_license_not_loaded(guint32 album_id, TrackList *songs)
+void VCMAWindow::on_track_license_not_loaded(guint32 track_id, TrackList *songs)
 {
-  on_album_license_loaded(album_id, "Unknown", Glib::RefPtr<Gdk::Pixbuf>(0), 0.0, songs);
+  on_track_license_loaded(track_id, "Unknown", Glib::RefPtr<Gdk::Pixbuf>(0), songs);
 }
 
-void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, double rating, TrackList *songs)
+void VCMAWindow::on_track_license_loaded(guint32 track_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, TrackList *songs)
 {
   std::string l = license;
   bool completely_filled = true;
@@ -375,10 +376,9 @@ void VCMAWindow::on_album_license_loaded(guint32 album_id, Glib::ustring license
   for (TrackList::const_iterator i = songs->get_tracks().begin(); 
        i != songs->get_tracks().end(); i++)
     {
-      if ((*i)->get_album_id() == album_id)
+      if ((*i)->get_track_id() == track_id)
         {
           (*i)->set_license(license);
-          (*i)->set_album_rating(rating);
           if (license.find("nd") == Glib::ustring::npos && license != "Unknown")
             {
               add_song_row(**i, license_image);
@@ -439,11 +439,69 @@ void VCMAWindow::cell_data_license(Gtk::CellRenderer *renderer, const Gtk::TreeI
   */
 }
 
+//from kde. gpl.
+static size_t
+get_word(char *string)
+{
+  int tab_size = 2;
+  register int i = 0, word_len = 0;
+
+  if (!string[0])
+    return 0;
+  while (isspace(string[i]))
+    {
+      if ('\t' == string[i])
+        {
+          if (0 == tab_size)
+            string[i] = ' ';
+          else  word_len += tab_size-1;
+        }
+      else if ('\n' == string[i])
+        string[i]=' ';
+      word_len++;
+      i++;
+    }
+  while (string[i] && !isspace(string[i++]))
+    word_len++;
+  return word_len;
+}
+
+char *
+word_wrap (char *string, size_t line_len)
+{
+  size_t len,                         /* length of current word */
+         current_len = 0;             /* current length of line */
+  size_t start_line = 0;              /* index of beginning if line */
+
+  while (0 != (len = get_word(&string[current_len + start_line])))
+    {
+      if (current_len + len < line_len)
+        current_len += len;
+      else
+        {
+          string[start_line+current_len] = '\n';
+          start_line += current_len + 1;
+          current_len = 0;
+        }
+    }
+  return string;
+}
+
+void VCMAWindow::cell_data_genre (Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
+{
+  Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  Glib::ustring genre = (*i)[songs_columns.genre];
+  char *s = strdup(genre.c_str());
+  char *t = word_wrap(s, 21);
+  cell->property_text() = std::string(t);
+  free (t);
+}
+
 void VCMAWindow::cell_data_song_and_artist(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
 {
   Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
-  cell->property_markup() = "<b>" + (*i)[songs_columns.song_title] + 
-    "</b>\nby: <u>" + (*i)[songs_columns.artist_name] +"</u>";
+  cell->property_text() = "" + (*i)[songs_columns.song_title] + 
+    "\nby: " + (*i)[songs_columns.artist_name] +"";
 }
 
 void VCMAWindow::cell_data_rating(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
