@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2012 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -64,6 +64,10 @@ class VCMAWindow: public Gtk::Window
     Gtk::TreeViewColumn license_column;
     void cell_data_license(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
 
+    Gtk::CellRendererText genre_renderer;
+    Gtk::TreeViewColumn genre_column;
+    void cell_data_genre(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
+
     Gtk::CellRendererText song_and_artist_renderer;
     Gtk::TreeViewColumn song_and_artist_column;
     void cell_data_song_and_artist(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
@@ -113,8 +117,8 @@ class VCMAWindow: public Gtk::Window
     void on_play_clicked();
     void on_details_clicked();
 
-    void on_album_license_not_loaded(guint32 album_id, TrackList *songs);
-    void on_album_license_loaded(guint32 album_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, double rating, TrackList *songs);
+    void on_track_license_not_loaded(guint32 track_id, TrackList *songs);
+    void on_track_license_loaded(guint32 track_id, Glib::ustring license, Glib::RefPtr<Gdk::Pixbuf> license_image, TrackList *songs);
     void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
                                int, int, 
                                const Gtk::SelectionData& selection_data,
